import shelve
import os


def open_shelve():
    # create dir if not exists
    try:
        os.makedirs(os.getenv("HOME") + '/.xboomx')
    except:
        pass

    # open shelve
    return shelve.open(os.getenv("HOME") + '/.xboomx/xboomx.db')



import os
import json
import logging


def load_config():
    try:
        with open(os.getenv("HOME") + "/.xboomx/config") as config_file:
            return json.loads('\n'.join(config_file.readlines()))
    except:
        logging.error("Failed to load config file")
        return {}


config = load_config()



#!/usr/bin/python
import fileinput
import xboomx.db


def main():
    # open db
    db = xboomx.db.open_shelve()

    # get item to update
    item = fileinput.input().next()
    item = item.strip('\n')

    # update item
    db[item] = db.get(item, 0) + 1

    # print it
    print item

    # clean up
    db.sync()
    db.close()


main()



#!/usr/bin/python
import fileinput
import xboomx.db


def main():
    # open shelve
    db = xboomx.db.open_shelve()

    # read lines and set weight according to db
    items = []

    for input_item in fileinput.input():
        input_item = input_item.strip('\n')
        items.append((db.get(input_item, 0), input_item))

    # sort items
    items.sort(key=lambda x: x[0], reverse=True)

    # print items
    for item in items:
        print item[1]

    # clean up
    db.close()


main()
